Ordinary differential equations solvers
Rk2 is an explicit Runge-Kutta of order 2 with 2 steps, it is suitable for
non stiff systems.
Rk4 is an explicit Runge-Kutta of order 4 with 4 steps, it is suitable for
non stiff systems.
Rkf45 is an explicit Runge-Kutta-Fehlberg of order 4 and 5 with 6 steps
and adaptive integration step, it is suitable for non stiff systems.
Radau is an implicit Runge-Kutta-Radau of order 3 with 2 steps, it is
suitable for stiff systems.
Structs
- Radau
- Struct for the time evolution of the linear system using the implicit Radau method of order 3 with 2 steps
- Rk
- Struct for the time evolution of a linear system
- Rkf45
- Struct for the time evolution of a linear system
- Step
- Struct to hold the data of the linear system time evolution
- Step
With Error - Struct to hold the data of the linear system time evolution
Traits
- Radau
Const - Trait that defines the constants used in the Radau solver.
- RkConst
- Trait that defines the constants used in the Rk solver.
- Rkf45
Const - Trait that defines the constants used in the Rkf45 solver.